@@ -29,6 +29,9 @@ from ocrfeeder.util import TEXT_TYPE, IMAGE_TYPE, ALIGN_LEFT, ALIGN_RIGHT, ALIGN
     ALIGN_FILL
 from ocrfeeder.util.graphics import getImagePrintSize
 from ocrfeeder.util.lib import debug
+from reportlab.pdfgen import canvas
+from reportlab.lib import units
+from reportlab.lib.utils import ImageReader
 import math
 import os.path
 import shutil
@@ -335,7 +338,7 @@ class PlaintextGenerator(DocumentGenerator):
     def __init__(self, name):
         self.name = name
         self.text = ''
-        
+
     def addText(self, newText):
         self.text += newText
 
@@ -349,3 +352,62 @@ class PlaintextGenerator(DocumentGenerator):
                 f.close() # Close the file
         except IOError:
             pass
+
+class PdfGenerator(DocumentGenerator):
+
+    def __init__(self, name, from_scratch = False):
+        self.name = name
+        self._from_scratch = from_scratch
+        self.canvas = canvas.Canvas(self.name)
+        self.page_data = None
+
+    def addText(self, box):
+        x, y, width, height = box.getBoundsPrintSize(self.page_data.resolution)
+        text = self.canvas.beginText()
+        # Make the text transparent if we are not
+        # creating a PDF from scratch
+        if not self._from_scratch:
+            text.setTextRenderMode(3)
+        text.setTextOrigin(x * units.inch,
+                           (self.page_data.height - y) * units.inch)
+        text.setCharSpace(box.text_data.letter_space)
+        text.setLeading(box.text_data.line_space + box.text_data.size)
+        text.moveCursor(0, box.text_data.size)
+        try:
+            self.setFont(box.text_data.face,
+                         box.text_data.size)
+        except:
+            debug('Error setting font %s' % box.text_data.face)
+            self.canvas.setFontSize(box.text_data.size)
+        text.textLines(box.text)
+        self.canvas.drawText(text)
+
+    def addImage(self, box):
+        # Do nothing as the images will be already
+        # seen in the PDF
+        if not self._from_scratch:
+            return
+        x, y, width, height = box.getBoundsPrintSize(self.page_data.resolution)
+        self.canvas.drawInlineImage(box.image,
+                                    x * units.inch,
+                                    (self.page_data.height - (y + height)) * \
+                                        units.inch,
+                                    width * units.inch,
+                                    height * units.inch)
+
+    def addPage(self, page_data):
+        self.canvas.setPageSize((page_data.width * units.inch,
+                                 page_data.height * units.inch))
+        self.page_data = page_data
+        # Paste the source image that users will read
+        # in the PDF
+        if not self._from_scratch:
+            image = ImageReader(page_data.image_path)
+            self.canvas.drawImage(image, 0, 0,
+                                  page_data.width * units.inch,
+                                  page_data.height * units.inch)
+        self.addBoxes(page_data.data_boxes)
+        self.canvas.showPage()
+
+    def save(self):
+        self.canvas.save()
