@@ -42,7 +42,6 @@ import gtk
 
 class Studio:
 
-    EXPORT_FORMATS = ['HTML', 'ODT']
     TARGET_TYPE_URI_LIST = 80
 
     def __init__(self):
@@ -58,14 +57,20 @@ class Studio:
         language = gettext.translation(OCRFEEDER_COMPACT_NAME, LOCALE_DIR,
                                        languages = languages, fallback = True)
         _ = language.gettext
+
+        self.EXPORT_FORMATS = {0: (self.exportToOdt, _('ODT')),
+                               1: (self.exportToHtml, _('HTML')),
+                               2: (self.exportToPdf, _('PDF')),
+                               3: (self.exportToPlaintext, _('Plain Text'))}
+
         self.title = OCRFEEDER_STUDIO_NAME
         self.main_window = widgetPresenter.MainWindow()
         self.main_window.setTitle(self.title)
         self.configuration_manager = ConfigurationManager()
         self.ocr_engines_manager = OcrEnginesManager(self.configuration_manager)
+        self.configuration_manager.loadConfiguration()
         self.ocr_engines_manager.makeEnginesFromFolder(self.configuration_manager.user_engines_folder)
         self.ocr_engines = self.ocr_engines_manager.ocr_engines
-        self.configuration_manager.loadConfiguration()
         self.source_images_selector = SourceImagesSelector()
         self.source_images_selector.connect('selection_changed', self.selectionChanged)
         self.source_images_icon_view = SourceImagesSelectorIconView(self.source_images_selector)
@@ -83,8 +88,9 @@ class Studio:
                                                                self.configuration_manager)
         self.project_name = None
 
-        toolbar_callback_dict = {'detection': self.__recognizeCurrentPageAction,
-                         'export_to_odt': self.exportToOdt}
+        toolbar_callback_dict = {'recognizePage': self.__recognizePageAction,
+                                 'recognizeDocument': self.__recognizeDocumentAction,
+                                 'export_to_odt': self.exportToOdt}
 
         menubar_callback_dict = {'exit': self.quit, 'add_image': self.addImage, 'export_to_odt': self.exportToOdt, 'edit_page': self.choosePageSize,
                                  'delete_page': self.deleteCurrentPage, 'export_dialog': self.exportDialog, 'add_folder': self.addFolder,
@@ -101,7 +107,8 @@ class Studio:
                                  'delete_selected_areas': self.source_images_controler.deleteSelectedAreas,
                                  'image_deskewer': self.source_images_controler.deskewCurrentImage,
                                  'copy_to_clipboard': self.source_images_controler.copyRecognizedTextToClipboard,
-                                 'spell_checker': self.spellChecker
+                                 'spell_checker': self.spellChecker,
+                                 'help_contents': self.showHelpContents,
                                  }
 
         self.main_window.setHeader(menubar_callback_dict, toolbar_callback_dict)
@@ -111,7 +118,8 @@ class Studio:
         parser.add_option('-i', '--images', dest = 'images',
                           action = 'append', type = 'string',
                           metavar = 'IMAGE1 [IMAGE2, ...]', default = [],
-                          help = 'images to be automatically added on start-up')
+                          help = 'images to be automatically added on start-up. '
+                                 'Use the option before every image path.')
         parser.add_option('-d', '--dir', dest = 'directory',
                           action = 'store', type = 'string',
                           help = 'directory with images to be added'
@@ -188,7 +196,7 @@ class Studio:
                                                         self.main_window.window)
         item_obtain = AsyncItem(lib.obtainScanners,(),
                                 self.__obtainScannersFinishedCb,(dialog,))
-        info_obtain = (_('Obtaining scanners'), _('Please wait…'))
+        info_obtain = (_('Obtaining scanners'), _(u'Please wait…'))
         dialog.setItemsList([(info_obtain, item_obtain)])
         dialog.run()
 
@@ -214,7 +222,7 @@ class Studio:
                 self.main_window.window)
             item_scan = AsyncItem(lib.scan,(device,),
                                   self.__scanFinishedCb,(dialog_scan,))
-            info_scan = (_('Scanning'), _('Please wait…'))
+            info_scan = (_('Scanning'), _(u'Please wait…'))
             dialog_scan.setItemsList([(info_scan, item_scan)])
             dialog_scan.run()
         else:
@@ -256,7 +264,7 @@ class Studio:
                               self.configuration_manager.temporary_dir),
                              self.__loadPdfFinishedCb,
                              (dialog,))
-            info = (_('Loading PDF'), _('Please wait…'))
+            info = (_('Loading PDF'), _(u'Please wait…'))
             dialog.setItemsList([(info, item)])
             dialog.run()
 
@@ -268,7 +276,9 @@ class Studio:
         file_open_dialog = widgetPresenter.FileDialog('select-folder')
         response = file_open_dialog.run()
         if response == gtk.RESPONSE_OK:
-            for folder in file_open_dialog.get_filenames():
+            filenames = file_open_dialog.get_filenames()
+            file_open_dialog.destroy()
+            for folder in filenames:
                 self.__addImagesToReviewer(lib.getImagesFromFolder(folder))
         file_open_dialog.destroy()
 
@@ -278,13 +288,53 @@ class Studio:
     def exportToOdt(self, widget = None):
         self.source_images_controler.exportPagesToOdt(self.source_images_selector.getPixbufsSorted())
 
+    def exportToPlaintext(self, widget = None):
+        self.source_images_controler.exportPagesToPlaintext(self.source_images_selector.getPixbufsSorted())
+
+    def exportToPdf(self, widget = None):
+        ask_pdf_type_dialog = gtk.MessageDialog(self.main_window.window,
+                      gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                      buttons = gtk.BUTTONS_OK_CANCEL)
+        ask_pdf_type_dialog.set_markup(_('What kind of PDF document do you '
+                                         'wish?'))
+        pdf_from_scratch_radio = gtk.RadioButton(label= _('From scratch'))
+        pdf_from_scratch_radio.set_tooltip_text(
+                                    _('Creates a new PDF from scratch.'))
+        searchable_pdf_radio = gtk.RadioButton(pdf_from_scratch_radio,
+                                               _('Searchable PDF'))
+        searchable_pdf_radio.set_tooltip_text(_('Creates a PDF based on '
+                                                'the images but with searchable '
+                                                'text.'))
+        vbox = gtk.VBox(True)
+        vbox.add(pdf_from_scratch_radio)
+        vbox.add(searchable_pdf_radio)
+        content_area = ask_pdf_type_dialog.get_content_area()
+        content_area.add(vbox)
+        content_area.show_all()
+
+        response = ask_pdf_type_dialog.run()
+        ask_pdf_type_dialog.destroy()
+        if response == gtk.RESPONSE_CANCEL:
+            return
+
+        pdf_from_scratch = True
+        if searchable_pdf_radio.get_active():
+            pdf_from_scratch = False
+        self.source_images_controler.exportPagesToPdf(
+             self.source_images_selector.getPixbufsSorted(),
+             pdf_from_scratch)
+
     def exportDialog(self, widget):
-        export_dialog = widgetPresenter.ExportDialog(_('Export pages'), self.EXPORT_FORMATS)
+        format_names = [format[1] for format in self.EXPORT_FORMATS.values()]
+        export_dialog = widgetPresenter.ExportDialog(_('Export pages'), format_names)
         response = export_dialog.run()
         if response == gtk.RESPONSE_ACCEPT:
-            format = export_dialog.getSelectedFormat().capitalize()
+            format = export_dialog.getSelectedFormat()
             export_dialog.destroy()
-            exec('self.exportTo%s()' % format)
+            if format != -1:
+                # Retrieve and run the exportation function
+                exportation_function = self.EXPORT_FORMATS[format][0]
+                exportation_function()
             return None
         export_dialog.destroy()
         return None
@@ -305,9 +355,12 @@ class Studio:
             return
         self.source_images_controler.addImages(images)
 
-    def __recognizeCurrentPageAction(self, widget):
+    def __recognizePageAction(self, widget):
         self.source_images_controler.recognizeCurrentPage()
 
+    def __recognizeDocumentAction(self, widget):
+        self.source_images_controler.recognizeDocument()
+
     def setProjectName(self, project_name):
         self.project_name = project_name
         project_title = os.path.splitext(os.path.basename(self.project_name))[0]
@@ -337,7 +390,12 @@ class Studio:
             self.setProjectName(project_title)
 
     def clear(self, widget = None):
-        self.source_images_controler.clear()
+        dialog = widgetPresenter.QuestionDialog(_('Are you sure you want '
+                                                  'to clear the project?'))
+        response = dialog.run()
+        if response == gtk.RESPONSE_YES:
+            self.source_images_controler.clear()
+        dialog.destroy()
 
     def unpaper(self, widget = None):
         self.source_images_controler.unpaperTool()
@@ -370,6 +428,11 @@ class Studio:
         if about_dialog.run():
             about_dialog.destroy()
 
+    def showHelpContents(self, widget = None):
+        gtk.show_uri(self.main_window.window.get_screen(),
+                     'ghelp:ocrfeeder',
+                     gtk.get_current_event_time())
+
     def zoomIn(self, widget = None):
         self.source_images_controler.zoomIn()
 
