@@ -20,7 +20,7 @@
 
 from customWidgets import SelectableBoxesArea
 from dataHolder import DataBox, PageData, TEXT_TYPE, IMAGE_TYPE
-from ocrfeeder.feeder.documentGeneration import OdtGenerator, HtmlGenerator, PlaintextGenerator
+from ocrfeeder.feeder.documentGeneration import OdtGenerator, HtmlGenerator, PlaintextGenerator, PdfGenerator
 from ocrfeeder.feeder.imageManipulation import *
 from ocrfeeder.feeder.layoutAnalysis import *
 from pango import FontDescription, SCALE
@@ -709,6 +709,18 @@ class ImageReviewer_Controler:
                 document_generator.addText(image_reviewer.getAllText())
             document_generator.save()
 
+    def exportPagesToPdf(self, pixbufs_sorted = [], pdf_from_scratch = True):
+        image_reviewers = self.__askForNumberOfPages(_('Export to PDF'),
+                                                     pixbufs_sorted)
+        if not image_reviewers:
+            return
+        file_name = self.__askForFileName()
+        if file_name:
+            document_generator = PdfGenerator(file_name, pdf_from_scratch)
+            for image_reviewer in image_reviewers:
+                document_generator.addPage(image_reviewer.getPageData())
+            document_generator.save()
+
     def saveProjectAs(self):
         return self.__askForFileName(extension = '.ocrf')
 
